bayespy.inference.vmp.nodes.gaussian.GaussianGammaARDDistribution.plates_to_parent
==================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaARDDistribution.plates_to_parent